Ext.define( 'QDesk.view.widget.WSearchField', {
  extend : 'Ext.form.field.Text',

  alias : 'widget.WSearchField',

  triggers : {
    clear : {
      weight : 0,
      cls : Ext.baseCSSPrefix + 'form-clear-trigger',
      hidden : true,
      handler : 'onClearClick',
      scope : 'this'
    },
    search : {
      weight : 1,
      cls : Ext.baseCSSPrefix + 'form-search-trigger',
      handler : 'onSearchClick',
      scope : 'this'
    }
  },


  initComponent : function ()
  {
    var me = this;

    me.callParent( arguments );

    me.on( 'specialkey', function ( f, e )
    {
      if ( e.getKey() == e.ENTER )
      {
        me.onSearchClick();
      }
    } );

    if ( !me.store || !me.store.isStore )
    {
      me.store = Ext.data.StoreManager.lookup( me.store );
    }
  },


  onClearClick : function ()
  {
    var me = this;

    if ( me.hasSearch )
    {
      me.setValue( '' );

      var extraParams = me.store.getProxy().extraParams;
      if ( extraParams && extraParams[ me.paramName ] )
      {
        delete extraParams[ me.paramName ];
        me.store.getProxy().extraParams = extraParams;
        me.store.load();
      }

      me.hasSearch = false;
      me.getTrigger( 'clear' ).hide();
      me.updateLayout();
    }
  },


  onSearchClick : function ()
  {
    var me = this;
    var value = me.getValue();

    if ( value.length > 0 )
    {
      var extraParams = me.store.getProxy().extraParams;
      extraParams = extraParams || {};
      extraParams[ me.paramName ] = value;

      me.store.getProxy().extraParams = extraParams;
      me.store.load();

      me.hasSearch = true;
      me.getTrigger( 'clear' ).show();
      me.updateLayout();
    }
    else
    {
      // if the filter value is empty, we hide the clear button
      if ( me.getTrigger( 'clear' ).isVisible() )
      {
        me.hasSearch = true;  // important so that the store is reloaded
        me.onClearClick();
      }
    }
  },


  afterRender : function ()
  {
    this.callParent();
    //this.getTrigger( 'clear' ).hide();
  }
} );